==> osidb_bindings-4.10.1.tar.gz: osidb_bindings-4.10.1/osidb_bindings/bindings/python_client/models/osidb_api_v1_flaws_list_order_item.py <==
from enum import Enum


class OsidbApiV1FlawsListOrderItem(str, Enum):
    ACKNOWLEDGMENTS_AFFILIATION = "acknowledgments__affiliation"
    ACKNOWLEDGMENTS_CREATED_DT = "acknowledgments__created_dt"
    ACKNOWLEDGMENTS_FROM_UPSTREAM = "acknowledgments__from_upstream"
    ACKNOWLEDGMENTS_NAME = "acknowledgments__name"
    ACKNOWLEDGMENTS_UPDATED_DT = "acknowledgments__updated_dt"
    ACKNOWLEDGMENTS_UUID = "acknowledgments__uuid"
    AFFECTS_AFFECTEDNESS = "affects__affectedness"
    AFFECTS_CREATED_DT = "affects__created_dt"
    AFFECTS_IMPACT = "affects__impact"
    AFFECTS_PS_COMPONENT = "affects__ps_component"
    AFFECTS_PS_MODULE = "affects__ps_module"
    AFFECTS_RESOLUTION = "affects__resolution"
    AFFECTS_TRACKERS_CREATED_DT = "affects__trackers__created_dt"
    AFFECTS_TRACKERS_ERRATA_ADVISORY_NAME = "affects__trackers__errata__advisory_name"
    AFFECTS_TRACKERS_ERRATA_ET_ID = "affects__trackers__errata__et_id"
    AFFECTS_TRACKERS_ERRATA_SHIPPED_DT = "affects__trackers__errata__shipped_dt"
    AFFECTS_TRACKERS_EXTERNAL_SYSTEM_ID = "affects__trackers__external_system_id"
    AFFECTS_TRACKERS_PS_UPDATE_STREAM = "affects__trackers__ps_update_stream"
    AFFECTS_TRACKERS_RESOLUTION = "affects__trackers__resolution"
    AFFECTS_TRACKERS_STATUS = "affects__trackers__status"
    AFFECTS_TRACKERS_TYPE = "affects__trackers__type"
    AFFECTS_TRACKERS_UPDATED_DT = "affects__trackers__updated_dt"
    AFFECTS_TRACKERS_UUID = "affects__trackers__uuid"
    AFFECTS_UPDATED_DT = "affects__updated_dt"
    AFFECTS_UUID = "affects__uuid"
    BZ_ID = "bz_id"
    COMMENT_ZERO = "comment_zero"
    COMPONENTS = "components"
    CREATED_DT = "created_dt"
    CVE_DESCRIPTION = "cve_description"
    CVE_ID = "cve_id"
    CVSS_SCORES_COMMENT = "cvss_scores__comment"
    CVSS_SCORES_CREATED_DT = "cvss_scores__created_dt"
    CVSS_SCORES_ISSUER = "cvss_scores__issuer"
    CVSS_SCORES_SCORE = "cvss_scores__score"
    CVSS_SCORES_UPDATED_DT = "cvss_scores__updated_dt"
    CVSS_SCORES_UUID = "cvss_scores__uuid"
    CVSS_SCORES_VECTOR = "cvss_scores__vector"
    CWE_ID = "cwe_id"
    EMBARGOED = "embargoed"
    IMPACT = "impact"
    MAJOR_INCIDENT_START_DT = "major_incident_start_dt"
    MAJOR_INCIDENT_STATE = "major_incident_state"
    NIST_CVSS_VALIDATION = "nist_cvss_validation"
    OWNER = "owner"
    REFERENCES_CREATED_DT = "references__created_dt"
    REFERENCES_DESCRIPTION = "references__description"
    REFERENCES_TYPE = "references__type"
    REFERENCES_UPDATED_DT = "references__updated_dt"
    REFERENCES_URL = "references__url"
    REFERENCES_UUID = "references__uuid"
    REPORTED_DT = "reported_dt"
    REQUIRES_CVE_DESCRIPTION = "requires_cve_description"
    SOURCE = "source"
    STATEMENT = "statement"
    TEAM_ID = "team_id"
    TITLE = "title"
    UNEMBARGO_DT = "unembargo_dt"
    UPDATED_DT = "updated_dt"
    UUID = "uuid"
    VALUE_0 = "-acknowledgments__affiliation"
    VALUE_1 = "-acknowledgments__created_dt"
    VALUE_10 = "-affects__ps_module"
    VALUE_11 = "-affects__resolution"
    VALUE_12 = "-affects__trackers__created_dt"
    VALUE_13 = "-affects__trackers__errata__advisory_name"
    VALUE_14 = "-affects__trackers__errata__et_id"
    VALUE_15 = "-affects__trackers__errata__shipped_dt"
    VALUE_16 = "-affects__trackers__external_system_id"
    VALUE_17 = "-affects__trackers__ps_update_stream"
    VALUE_18 = "-affects__trackers__resolution"
    VALUE_19 = "-affects__trackers__status"
    VALUE_2 = "-acknowledgments__from_upstream"
    VALUE_20 = "-affects__trackers__type"
    VALUE_21 = "-affects__trackers__updated_dt"
    VALUE_22 = "-affects__trackers__uuid"
    VALUE_23 = "-affects__updated_dt"
    VALUE_24 = "-affects__uuid"
    VALUE_25 = "-bz_id"
    VALUE_26 = "-comment_zero"
    VALUE_27 = "-components"
    VALUE_28 = "-created_dt"
    VALUE_29 = "-cve_description"
    VALUE_3 = "-acknowledgments__name"
    VALUE_30 = "-cve_id"
    VALUE_31 = "-cvss_scores__comment"
    VALUE_32 = "-cvss_scores__created_dt"
    VALUE_33 = "-cvss_scores__issuer"
    VALUE_34 = "-cvss_scores__score"
    VALUE_35 = "-cvss_scores__updated_dt"
    VALUE_36 = "-cvss_scores__uuid"
    VALUE_37 = "-cvss_scores__vector"
    VALUE_38 = "-cwe_id"
    VALUE_39 = "-embargoed"
    VALUE_4 = "-acknowledgments__updated_dt"
    VALUE_40 = "-impact"
    VALUE_41 = "-major_incident_start_dt"
    VALUE_42 = "-major_incident_state"
    VALUE_43 = "-nist_cvss_validation"
    VALUE_44 = "-owner"
    VALUE_45 = "-references__created_dt"
    VALUE_46 = "-references__description"
    VALUE_47 = "-references__type"
    VALUE_48 = "-references__updated_dt"
    VALUE_49 = "-references__url"
    VALUE_5 = "-acknowledgments__uuid"
    VALUE_50 = "-references__uuid"
    VALUE_51 = "-reported_dt"
    VALUE_52 = "-requires_cve_description"
    VALUE_53 = "-source"
    VALUE_54 = "-statement"
    VALUE_55 = "-team_id"
    VALUE_56 = "-title"
    VALUE_57 = "-unembargo_dt"
    VALUE_58 = "-updated_dt"
    VALUE_59 = "-uuid"
    VALUE_6 = "-affects__affectedness"
    VALUE_60 = "-workflow_state"
    VALUE_7 = "-affects__created_dt"
    VALUE_8 = "-affects__impact"
    VALUE_9 = "-affects__ps_component"
    WORKFLOW_STATE = "workflow_state"

    def __str__(self) -> str:
        return str(self.value)

==> osidb_bindings-5.0.0b3.tar.gz: osidb_bindings-5.0.0b3/osidb_bindings/bindings/python_client/models/osidb_api_v1_flaws_list_order_item.py <==
from enum import Enum


class OsidbApiV1FlawsListOrderItem(str, Enum):
    ACKNOWLEDGMENTS_AFFILIATION = "acknowledgments__affiliation"
    ACKNOWLEDGMENTS_CREATED_DT = "acknowledgments__created_dt"
    ACKNOWLEDGMENTS_FROM_UPSTREAM = "acknowledgments__from_upstream"
    ACKNOWLEDGMENTS_NAME = "acknowledgments__name"
    ACKNOWLEDGMENTS_UPDATED_DT = "acknowledgments__updated_dt"
    ACKNOWLEDGMENTS_UUID = "acknowledgments__uuid"
    AFFECTS_AFFECTEDNESS = "affects__affectedness"
    AFFECTS_CREATED_DT = "affects__created_dt"
    AFFECTS_IMPACT = "affects__impact"
    AFFECTS_PS_COMPONENT = "affects__ps_component"
    AFFECTS_PS_MODULE = "affects__ps_module"
    AFFECTS_RESOLUTION = "affects__resolution"
    AFFECTS_TRACKER_CREATED_DT = "affects__tracker__created_dt"
    AFFECTS_TRACKER_ERRATA_ADVISORY_NAME = "affects__tracker__errata__advisory_name"
    AFFECTS_TRACKER_ERRATA_ET_ID = "affects__tracker__errata__et_id"
    AFFECTS_TRACKER_ERRATA_SHIPPED_DT = "affects__tracker__errata__shipped_dt"
    AFFECTS_TRACKER_EXTERNAL_SYSTEM_ID = "affects__tracker__external_system_id"
    AFFECTS_TRACKER_PS_UPDATE_STREAM = "affects__tracker__ps_update_stream"
    AFFECTS_TRACKER_RESOLUTION = "affects__tracker__resolution"
    AFFECTS_TRACKER_STATUS = "affects__tracker__status"
    AFFECTS_TRACKER_TYPE = "affects__tracker__type"
    AFFECTS_TRACKER_UPDATED_DT = "affects__tracker__updated_dt"
    AFFECTS_TRACKER_UUID = "affects__tracker__uuid"
    AFFECTS_UPDATED_DT = "affects__updated_dt"
    AFFECTS_UUID = "affects__uuid"
    BZ_ID = "bz_id"
    COMMENT_ZERO = "comment_zero"
    COMPONENTS = "components"
    CREATED_DT = "created_dt"
    CVE_DESCRIPTION = "cve_description"
    CVE_ID = "cve_id"
    CVSS_SCORES_COMMENT = "cvss_scores__comment"
    CVSS_SCORES_CREATED_DT = "cvss_scores__created_dt"
    CVSS_SCORES_ISSUER = "cvss_scores__issuer"
    CVSS_SCORES_SCORE = "cvss_scores__score"
    CVSS_SCORES_UPDATED_DT = "cvss_scores__updated_dt"
    CVSS_SCORES_UUID = "cvss_scores__uuid"
    CVSS_SCORES_VECTOR = "cvss_scores__vector"
    CWE_ID = "cwe_id"
    EMBARGOED = "embargoed"
    IMPACT = "impact"
    MAJOR_INCIDENT_START_DT = "major_incident_start_dt"
    MAJOR_INCIDENT_STATE = "major_incident_state"
    NIST_CVSS_VALIDATION = "nist_cvss_validation"
    OWNER = "owner"
    REFERENCES_CREATED_DT = "references__created_dt"
    REFERENCES_DESCRIPTION = "references__description"
    REFERENCES_TYPE = "references__type"
    REFERENCES_UPDATED_DT = "references__updated_dt"
    REFERENCES_URL = "references__url"
    REFERENCES_UUID = "references__uuid"
    REPORTED_DT = "reported_dt"
    REQUIRES_CVE_DESCRIPTION = "requires_cve_description"
    SOURCE = "source"
    STATEMENT = "statement"
    TEAM_ID = "team_id"
    TITLE = "title"
    UNEMBARGO_DT = "unembargo_dt"
    UPDATED_DT = "updated_dt"
    UUID = "uuid"
    VALUE_0 = "-acknowledgments__affiliation"
    VALUE_1 = "-acknowledgments__created_dt"
    VALUE_10 = "-affects__ps_module"
    VALUE_11 = "-affects__resolution"
    VALUE_12 = "-affects__tracker__created_dt"
    VALUE_13 = "-affects__tracker__errata__advisory_name"
    VALUE_14 = "-affects__tracker__errata__et_id"
    VALUE_15 = "-affects__tracker__errata__shipped_dt"
    VALUE_16 = "-affects__tracker__external_system_id"
    VALUE_17 = "-affects__tracker__ps_update_stream"
    VALUE_18 = "-affects__tracker__resolution"
    VALUE_19 = "-affects__tracker__status"
    VALUE_2 = "-acknowledgments__from_upstream"
    VALUE_20 = "-affects__tracker__type"
    VALUE_21 = "-affects__tracker__updated_dt"
    VALUE_22 = "-affects__tracker__uuid"
    VALUE_23 = "-affects__updated_dt"
    VALUE_24 = "-affects__uuid"
    VALUE_25 = "-bz_id"
    VALUE_26 = "-comment_zero"
    VALUE_27 = "-components"
    VALUE_28 = "-created_dt"
    VALUE_29 = "-cve_description"
    VALUE_3 = "-acknowledgments__name"
    VALUE_30 = "-cve_id"
    VALUE_31 = "-cvss_scores__comment"
    VALUE_32 = "-cvss_scores__created_dt"
    VALUE_33 = "-cvss_scores__issuer"
    VALUE_34 = "-cvss_scores__score"
    VALUE_35 = "-cvss_scores__updated_dt"
    VALUE_36 = "-cvss_scores__uuid"
    VALUE_37 = "-cvss_scores__vector"
    VALUE_38 = "-cwe_id"
    VALUE_39 = "-embargoed"
    VALUE_4 = "-acknowledgments__updated_dt"
    VALUE_40 = "-impact"
    VALUE_41 = "-major_incident_start_dt"
    VALUE_42 = "-major_incident_state"
    VALUE_43 = "-nist_cvss_validation"
    VALUE_44 = "-owner"
    VALUE_45 = "-references__created_dt"
    VALUE_46 = "-references__description"
    VALUE_47 = "-references__type"
    VALUE_48 = "-references__updated_dt"
    VALUE_49 = "-references__url"
    VALUE_5 = "-acknowledgments__uuid"
    VALUE_50 = "-references__uuid"
    VALUE_51 = "-reported_dt"
    VALUE_52 = "-requires_cve_description"
    VALUE_53 = "-source"
    VALUE_54 = "-statement"
    VALUE_55 = "-team_id"
    VALUE_56 = "-title"
    VALUE_57 = "-unembargo_dt"
    VALUE_58 = "-updated_dt"
    VALUE_59 = "-uuid"
    VALUE_6 = "-affects__affectedness"
    VALUE_60 = "-workflow_state"
    VALUE_7 = "-affects__created_dt"
    VALUE_8 = "-affects__impact"
    VALUE_9 = "-affects__ps_component"
    WORKFLOW_STATE = "workflow_state"

    def __str__(self) -> str:
        return str(self.value)
